@@ -14,6 +14,7 @@ class K2TPipeline:
         self,
         model: PreTrainedModel,
         tokenizer: PreTrainedTokenizer,
+
         use_cuda: bool
     ):
         self.model = model
@@ -46,7 +47,7 @@ class K2TPipeline:
             result += self.tokenizer.decode(outputs[0])
 
         result = re.sub("<pad>|</s>", "", result)
-        return result
+        return result.strip()
 
     def _prepare_inputs_for_k2t(self, keywords):
         text = str(keywords)
@@ -83,6 +84,12 @@ SUPPORTED_TASKS = {
         "default": {
             "model": "gagan3012/k2t",
         },
+    },
+    "k2t-tiny": {
+        "impl": K2TPipeline,
+        "default": {
+            "model": "gagan3012/k2t-tiny",
+        },
     }
 }
 
